This is the ailearn AI algorithm package. It includes four modules: Swarm, RL and utils.
In swarm module, particle swarm algorithm, artificial fish swarm algorithm and firefly algorithm are implemented.
The evolution strategy and the commonly used function to be optimized to evaluate the intelligent algorithm are also implemented in this module.
The RL module consists of two parts, the TabularRL part and the environment part.
The TabularRL part integrates some classical reinforcement learning algorithms, including Q-learning, Q(lambda), Sarsa, Sarsa(lambda), Dyna-Q, etc.
The environment part integrates some classic test environments of reinforcement learning, such as the frozen lake problem, cliffwalking problem, gridworld problem, etc.

Update history:
2018.4.10   0.1.3   In the first version, particle swarm optimization and artificial fish swarm algorithm are implemented for the first time and integrated into pip for the first time.
2018.4.16   0.1.4   The implementation of evolution strategy and evaluation module are added.
2018.4.18   0.1.5   Added TabularRL module and Environment module.
2018.4.19   0.1.8   The TabularRL module and environment module are integrated into RL module, the related description of the project is added, and the related protocol is updated.
2018.4.25   0.1.9   The output information has been changed from Chinese to English, and some known errors have been updated.
2019.1.15   0.2.0   The utils module is added, and some common functions are added, including distance measurement, evaluation function, PCA algorithm, mutual conversion between tag value and one hot code, Friedman detection, etc.; the NN module is added, and some common activation function and loss function are added; the swarm module algorithm is updated to make them update faster.
2020.5.14   0.2.1   Simplify the code and delete the NN module. Some functions are added, such as t-test, Friedman test and so on. Add RL classic environment windy gridworld environment.

Other updates:
1.


Project website:
https://pypi.org/project/ailearn/
https://github.com/axi345/ailearn/